pub struct BoxedRawValue(/* private fields */);Expand description
A wrapper around Box<serde_json::value::RawValue> which can be decoded directly from Postgres.
Methods from Deref<Target = RawValue>
sourcepub fn get(&self) -> &str
pub fn get(&self) -> &str
Access the JSON text underlying a raw value.
Example
use serde::Deserialize;
use serde_json::{Result, value::RawValue};
#[derive(Deserialize)]
struct Response<'a> {
code: u32,
#[serde(borrow)]
payload: &'a RawValue,
}
fn process(input: &str) -> Result<()> {
let response: Response = serde_json::from_str(input)?;
let payload = response.payload.get();
if payload.starts_with('{') {
// handle a payload which is a JSON map
} else {
// handle any other type
}
Ok(())
}
fn main() -> Result<()> {
process(r#" {"code": 200, "payload": {}} "#)?;
Ok(())
}Trait Implementations
sourceimpl Clone for BoxedRawValue
impl Clone for BoxedRawValue
sourcefn clone(&self) -> BoxedRawValue
fn clone(&self) -> BoxedRawValue
Returns a copy of the value. Read more
1.0.0 · sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moresourceimpl Debug for BoxedRawValue
impl Debug for BoxedRawValue
sourceimpl<'r> Decode<'r, Postgres> for BoxedRawValue
impl<'r> Decode<'r, Postgres> for BoxedRawValue
sourcefn decode(
value: <Postgres as HasValueRef<'r>>::ValueRef
) -> Result<Self, BoxDynError>
fn decode( value: <Postgres as HasValueRef<'r>>::ValueRef ) -> Result<Self, BoxDynError>
Decode a new value of this type using a raw value from the database.
sourceimpl Deref for BoxedRawValue
impl Deref for BoxedRawValue
sourceimpl<'r> Encode<'r, Postgres> for BoxedRawValue
impl<'r> Encode<'r, Postgres> for BoxedRawValue
sourcefn encode_by_ref(
&self,
out: &mut <Postgres as HasArguments<'r>>::ArgumentBuffer
) -> IsNull
fn encode_by_ref( &self, out: &mut <Postgres as HasArguments<'r>>::ArgumentBuffer ) -> IsNull
sourcefn encode(self, buf: &mut <DB as HasArguments<'q>>::ArgumentBuffer) -> IsNullwhere
Self: Sized,
fn encode(self, buf: &mut <DB as HasArguments<'q>>::ArgumentBuffer) -> IsNullwhere
Self: Sized,
Writes the value of
self into buf in the expected format for the database.fn produces(&self) -> Option<<DB as Database>::TypeInfo>
fn size_hint(&self) -> usize
sourceimpl From<BoxedRawValue> for Box<RawValue>
impl From<BoxedRawValue> for Box<RawValue>
sourcefn from(raw_value: BoxedRawValue) -> Self
fn from(raw_value: BoxedRawValue) -> Self
Converts to this type from the input type.
sourceimpl PartialEq for BoxedRawValue
impl PartialEq for BoxedRawValue
sourceimpl PgHasArrayType for BoxedRawValue
impl PgHasArrayType for BoxedRawValue
fn array_type_info() -> PgTypeInfo
fn array_compatible(ty: &PgTypeInfo) -> bool
sourceimpl Type<Postgres> for BoxedRawValue
impl Type<Postgres> for BoxedRawValue
sourcefn type_info() -> PgTypeInfo
fn type_info() -> PgTypeInfo
Returns the canonical SQL type for this Rust type. Read more
sourcefn compatible(ty: &PgTypeInfo) -> bool
fn compatible(ty: &PgTypeInfo) -> bool
Determines if this Rust type is compatible with the given SQL type. Read more
impl Eq for BoxedRawValue